@@ -28,6 +28,7 @@
 #include <openssl/ssl.h>
 #include "mssl.h"
 #endif
+#include <arpa/inet.h>
 
 #include "gen.h"
 #include "http.h"
@@ -94,6 +95,7 @@ void usage(void)
 	fprintf(stderr, "		>= warn, 2 if >= crit, otherwhise return 0\n");
 	fprintf(stderr, "-N x		Nagios mode 2: return 0 when all fine, 'x'\n");
 	fprintf(stderr, "		when anything failes\n");
+	fprintf(stderr, "-y ip[:port]   bind to ip-address (and thus interface) [/port]\n");
 	fprintf(stderr, "-q		quiet, only returncode\n");
 	fprintf(stderr, "-V		show the version\n\n");
 }
@@ -154,16 +156,39 @@ int main(int argc, char *argv[])
 	int fd = -1;
 	SSL *ssl_h = NULL;
 	BIO *s_bio;
+	struct sockaddr_in bind_to;
+	char bind_to_valid = 0;
 
 	if (page_size == -1)
 		page_size = 4096;
 
 	buffer = (char *)mymalloc(page_size, "receive buffer");
 
-	while((c = getopt(argc, argv, "XL:bBg:h:p:c:i:Gx:t:o:e:flqsmV?I:R:rn:N:z")) != -1)
+	while((c = getopt(argc, argv, "y:XL:bBg:h:p:c:i:Gx:t:o:e:flqsmV?I:R:rn:N:z")) != -1)
 	{
 		switch(c)
 		{
+			case 'y':
+				{
+					char *dummy = strchr(optarg, ':');
+
+					bind_to_valid = 1;
+
+					memset(&bind_to, 0x00, sizeof(bind_to));
+
+					if (dummy)
+					{
+						bind_to.sin_port = atoi(dummy + 1);
+						*dummy = 0x00;
+					}
+
+					if (inet_aton(optarg, &bind_to.sin_addr) == 0)
+					{
+						error_exit("cannot convert ip address '%s' (for -y)\n", optarg);
+					}
+				}
+				break;
+
 			case 'z':
 				show_fp = 1;
 				break;
@@ -453,7 +478,7 @@ int main(int argc, char *argv[])
 				have_resolved = 1;
 			}
 
-			fd = connect_to(&addr, port, timeout);
+			fd = connect_to(bind_to_valid?(struct sockaddr *)&bind_to:NULL, &addr, port, timeout);
 
 			if (fd == -3)	/* ^C pressed */
 				break;
